@@ -22,10 +22,10 @@
 import os
 
 import pytest
-import sh
 from molecule import logger
-from molecule.test.conftest import change_dir_to, run_command
+from molecule.test.conftest import change_dir_to
 from molecule.test.functional.conftest import metadata_lint_update
+from molecule.util import run_command
 
 # import change_dir_to, temp_dir
 
@@ -35,23 +35,29 @@ LOG = logger.get_logger(__name__)
 def test_command_init_scenario(temp_dir):
     """Verify that we can initialize a new scenario with this driver."""
     role_directory = os.path.join(temp_dir.strpath, "test-init")
-    options = {}
-    cmd = sh.molecule.bake("init", "role", "test-init", **options)
+    cmd = ["molecule", "init", "role", "test-init"]
     result = run_command(cmd)
-    assert result.exit_code == 0
+    assert result.returncode == 0
     metadata_lint_update(role_directory)
 
     with change_dir_to(role_directory):
         molecule_directory = pytest.helpers.molecule_directory()
         scenario_directory = os.path.join(molecule_directory, "test-scenario")
-        options = {
-            "role_name": "test-init",
-            "driver-name": "containers",
-        }
-        cmd = sh.molecule.bake("init", "scenario", "test-scenario", **options)
-        run_command(cmd)
+        cmd = [
+            "molecule",
+            "init",
+            "scenario",
+            "test-scenario",
+            "--role-name",
+            "test-init",
+            "--driver-name",
+            "containers",
+        ]
+        result = run_command(cmd)
+        assert result.returncode == 0
 
         assert os.path.isdir(scenario_directory)
 
-        cmd = sh.molecule.bake("test", "-s", "test-scenario")
-        run_command(cmd)
+        cmd = ["molecule", "test", "-s", "test-scenario"]
+        result = run_command(cmd)
+        assert result.returncode == 0
